@@ -51,11 +51,10 @@ using std::endl;
 
 #include <cassert>
 
-static inline GpgME::Error makeError( gpg_err_code_t code ) {
-  return GpgME::Error( gpg_err_make( (gpg_err_source_t)22, code ) );
-}
-
 namespace GpgME {
+  static inline Error makeError( gpg_err_code_t code ) {
+    return Error( gpg_err_make( (gpg_err_source_t)22, code ) );
+  }
 
   const char * Error::source() const {
     return gpgme_strsource( (gpgme_error_t)mErr );
@@ -480,7 +479,8 @@ namespace GpgME {
 
   std::vector<Key> Context::signingKeys() const {
     std::vector<Key> result;
-    for ( unsigned int i = 0 ; gpgme_key_t key = gpgme_signers_enum( d->ctx, i ) ; ++i )
+    gpgme_key_t key;
+    for ( unsigned int i = 0 ; key = gpgme_signers_enum( d->ctx, i ) ; ++i )
       result.push_back( Key( key, false ) );
     return result;
   }
@@ -705,23 +705,3 @@ GpgME::Error GpgME::checkEngine( GpgME::Protocol proto ) {
   return Error( gpgme_engine_check_version( p ) );
 }
 
-GIOChannel * GpgME::getGIOChannel( int fd ) {
-#ifdef HAVE_GPGME_GET_GIOCHANNEL
-    extern "C" GIOChannel * gpgme_get_giochannel( int );
-    return gpgme_get_giochannel( fd );
-#else
-    (void)fd;
-    return 0;
-#endif
-}
-
-QIODevice * GpgME::getQIODevice( int fd ) {
-#ifdef HAVE_GPGME_GET_QIODEVICE
-    extern "C" QIODevice * gpgme_get_qiodevice( int );
-    return gpgme_get_qiodevice( fd );
-#else
-    (void)fd;
-    return 0;
-#endif
-}
-
