@@ -40,6 +40,8 @@ ResourceFileConfig::ResourceFileConfig( QWidget *parent )
     : ConfigWidget( parent )
 {
   QGridLayout *mainLayout = new QGridLayout( this );
+  mainLayout->setMargin( 0 );
+  mainLayout->setSpacing( KDialog::spacingHint() );
 
   QLabel *label = new QLabel( i18n( "Format:" ), this );
   mFormatBox = new KComboBox( this );
