@@ -22,6 +22,7 @@
 #define KABC_RESOURCE_H
 
 #include "addressbook.h"
+#include "distributionlist.h"
 #include "plugin.h"
 #include "kresources/resource.h"
 
@@ -38,8 +39,16 @@ class KABC_EXPORT Ticket
     friend class Resource;
 
   public:
+    /**
+      Destroys the Ticket instance.
+    */
     ~Ticket();
 
+    /**
+      Returns the resource for which this ticket has been created.
+
+      @see Resource::createTicket()
+    */
     Resource *resource();
 
   private:
@@ -288,6 +297,8 @@ class KABC_EXPORT Resource : public KRES::Resource
 
     /**
       Writes the resource specific config to file.
+
+      @param group The config section to write into
      */
     virtual void writeConfig( KConfigGroup &group );
 
@@ -327,11 +338,15 @@ class KABC_EXPORT Resource : public KRES::Resource
 
     /**
       Insert an addressee into the resource.
+
+      @param addr The addressee to add
      */
     virtual void insertAddressee( const Addressee &addr );
 
     /**
       Removes an addressee from resource.
+
+      @param addr The addressee to remove
      */
     virtual void removeAddressee( const Addressee &addr );
 
@@ -391,14 +406,59 @@ class KABC_EXPORT Resource : public KRES::Resource
     virtual Addressee::List findByCategory( const QString &category );
 
     /**
-      Removes all addressees from the resource.
+      Removes all addressees and distribution lists from the resource.
      */
     virtual void clear();
 
+    /**
+      Adds a distribution @p list into this resource.
+
+      @param list The list to insert.
+     */
+    virtual void insertDistributionList( DistributionList *list );
+
+    /**
+      Removes a distribution @p list from this resource.
+
+      @param list The list to remove.
+     */
+    virtual void removeDistributionList( DistributionList *list );
+
+    /**
+      Returns a distribution list for the given @p identifier or @c 0
+
+      @param identifier The ID of the list for look for.
+     */
+    virtual DistributionList* findDistributionListByIdentifier( const QString& identifier );
+
+    /**
+      Returns a distribution list with the given @p name or @c 0
+
+      @param name The localized name of the list for look for.
+      @param caseSensitivity Whether to do string matching case sensitive or
+             case insensitive. Default is @c Qt::CaseSensitive
+     */
+    virtual DistributionList* findDistributionListByName( const QString &name, Qt::CaseSensitivity caseSensitivity = Qt::CaseSensitive );
+
+    /**
+      Returns a list of all distribution lists of this resource.
+     */
+    virtual QList<DistributionList*> allDistributionLists();
+
+    /**
+      Returns a list of names of all distribution lists of this resource.
+
+      Convenience function, equal to iterate over the list returned
+      by allDistributionLists()
+     */
+    virtual QStringList allDistributionListNames() const;
+
     /**
       @internal
 
       Sets the address book of the resource.
+
+      @param addr The address book to use
      */
     void setAddressBook( AddressBook *addr );
 
@@ -438,9 +498,25 @@ class KABC_EXPORT Resource : public KRES::Resource
     void savingError( Resource *resource, const QString &msg );
 
   protected:
+    /**
+      Factory method, just creates and returns a new Ticket for the given resource.
+
+      Needed by subclasses since the constructor of Ticket is private and only
+      this base class is a friend, effectively limiting "new Ticket(this)" to
+      resource implementations.
+    */
     Ticket *createTicket( Resource * );
+
+    /**
+      A mapping from KABC UIDs to the respective addressee.
+    */
     Addressee::Map mAddrMap;
 
+    /**
+      A mapping from unique identifiers to the respective distribution list.
+    */
+    DistributionListMap mDistListMap;
+
   private:
     class Private;
     Private *const d;
