@@ -23,7 +23,7 @@
 
 #include "blogger1.h"
 #include "blogger1_p.h"
-#include "blogposting.h"
+#include "blogpost.h"
 
 #include <kxmlrpcclient/client.h>
 
@@ -40,12 +40,14 @@ using namespace KBlog;
 Blogger1::Blogger1( const KUrl &server, QObject *parent )
   : Blog( server, *new Blogger1Private, parent )
 {
+  kDebug(5323) << "Blogger1()";
   setUrl( server );
 }
 
 Blogger1::Blogger1( const KUrl &server, Blogger1Private &dd, QObject *parent )
   : Blog( server, dd, parent )
 {
+  kDebug(5323) << "Blogger1()";
   setUrl( server );
 }
 
@@ -72,7 +74,7 @@ void Blogger1::fetchUserInfo()
 {
     Q_D(Blogger1);
     kDebug(5323) << "Fetch user's info...";
-    QList<QVariant> args( d->defaultArgs() );
+    QList<QVariant> args( d->blogger1Args() );
     d->mXmlRpcClient->call(
       "blogger.getUserInfo", args,
       this, SLOT( slotFetchUserInfo( const QList<QVariant>&, const QVariant& ) ),
@@ -83,113 +85,97 @@ void Blogger1::listBlogs()
 {
     Q_D(Blogger1);
     kDebug(5323) << "Fetch List of Blogs...";
-    QList<QVariant> args( d->defaultArgs() );
+    QList<QVariant> args( d->blogger1Args() );
     d->mXmlRpcClient->call(
       "blogger.getUsersBlogs", args,
       this, SLOT( slotListBlogs( const QList<QVariant>&, const QVariant& ) ),
       this, SLOT( slotError( int, const QString&, const QVariant& ) ) );
 }
 
-void Blogger1::listRecentPostings( int number )
+void Blogger1::listRecentPosts( int number )
 {
     Q_D(Blogger1);
     kDebug(5323) << "Fetching List of Posts...";
     QList<QVariant> args( d->defaultArgs( blogId() ) );
     args << QVariant( number );
     d->mXmlRpcClient->call(
-      "blogger.getRecentPosts", args,
-      this, SLOT( slotListRecentPostings( const QList<QVariant>&, const QVariant& ) ),
+      d->getCallFromFunction( Blogger1Private::GetRecentPosts ), args,
+      this, SLOT( slotListRecentPosts( const QList<QVariant>&, const QVariant& ) ),
       this, SLOT( slotError( int, const QString&, const QVariant& ) ),
                QVariant( number ) );
 }
 
-void Blogger1::fetchPosting( KBlog::BlogPosting *posting )
+void Blogger1::fetchPost( KBlog::BlogPost *post )
 {
-  if ( !posting ) {
-    kError(5323) << "Blogger1::modifyPosting: posting is null pointer";
+  if ( !post ) {
+    kError(5323) << "Blogger1::modifyPost: post is null pointer";
     return;
   }
      Q_D(Blogger1);
-     kDebug(5323) << "Fetching Posting with url" << posting->postingId();
-     QList<QVariant> args( d->defaultArgs( posting->postingId() ) );
-     unsigned int i= d->mCallCounter++; // multithreading problem? must be executed at once
-     d->mCallMap[ i ] = posting;
+     kDebug(5323) << "Fetching Post with url" << post->postId();
+     QList<QVariant> args( d->defaultArgs( post->postId() ) );
+     unsigned int i= d->mCallCounter++;
+     d->mCallMap[ i ] = post;
      d->mXmlRpcClient->call(
-       "blogger.getPost", args,
-       this, SLOT( slotFetchPosting( const QList<QVariant>&, const QVariant& ) ),
+       d->getCallFromFunction( Blogger1Private::FetchPost ), args,
+       this, SLOT( slotFetchPost( const QList<QVariant>&, const QVariant& ) ),
        this, SLOT( slotError( int, const QString&, const QVariant& ) ),
                 QVariant( i ) );
 }
 
-void Blogger1::modifyPosting( KBlog::BlogPosting *posting )
+void Blogger1::modifyPost( KBlog::BlogPost *post )
 {
   Q_D(Blogger1);
 
-  if ( !posting ) {
-    kError(5323) << "Blogger1::modifyPosting: posting is null pointer";
+  if ( !post ) {
+    kError(5323) << "Blogger1::modifyPost: post is null pointer";
     return;
   }
-    kDebug(5323) << "Uploading Posting with postingId" << posting->postingId();
+    kDebug(5323) << "Uploading Post with postId" << post->postId();
     unsigned int i= d->mCallCounter++;
-    d->mCallMap[ i ] = posting;
-    QList<QVariant> args( d->defaultArgs( posting->postingId() ) );
-    QStringList categories = posting->categories();
-    QString content = "<title>" + posting->title() + "</title>";
-    QStringList::const_iterator it;
-    for ( it = categories.constBegin(); it != categories.constEnd(); ++it ) {
-      content += "<category>" + *it + "</category>";
-    }
-    content += posting->content();
-    args << QVariant( content );
-    args << QVariant( !posting->isPrivate() );
+    d->mCallMap[ i ] = post;
+    QList<QVariant> args( d->defaultArgs( post->postId() ) );
+    d->readArgsFromPost( &args, *post );
     d->mXmlRpcClient->call(
-      "blogger.editPost", args,
-      this, SLOT( slotModifyPosting( const QList<QVariant>&, const QVariant& ) ),
+      d->getCallFromFunction( Blogger1Private::ModifyPost ), args,
+      this, SLOT( slotModifyPost( const QList<QVariant>&, const QVariant& ) ),
       this, SLOT( slotError( int, const QString&, const QVariant& ) ), QVariant( i ) );
 }
 
-void Blogger1::createPosting( KBlog::BlogPosting *posting )
+void Blogger1::createPost( KBlog::BlogPost *post )
 {
   Q_D(Blogger1);
-  if ( !posting ) {
-    kError(5323) << "Blogger1::createPosting: posting is null pointer";
+  if ( !post ) {
+    kError(5323) << "Blogger1::createPost: post is null pointer";
     return;
   }
     unsigned int i= d->mCallCounter++;
-    d->mCallMap[ i ] = posting;
-    kDebug(5323) << "Creating new Posting with blogid" << blogId();
+    d->mCallMap[ i ] = post;
+    kDebug(5323) << "Creating new Post with blogid" << blogId();
     QList<QVariant> args( d->defaultArgs( blogId() ) );
-    QStringList categories = posting->categories();
-    QString content = "<title>" + posting->title() + "</title>";
-    QStringList::const_iterator it;
-    for ( it = categories.constBegin(); it != categories.constEnd(); ++it ) {
-      content += "<category>" + *it + "</category>";
-    }
-    content += posting->content();
-    args << QVariant( content );
-    args << QVariant( !posting->isPrivate() );
+    d->readArgsFromPost( &args, *post );
     d->mXmlRpcClient->call(
-      "blogger.newPost", args,
-      this, SLOT( slotCreatePosting( const QList<QVariant>&, const QVariant& ) ),
+      d->getCallFromFunction( Blogger1Private::CreatePost ), args,
+      this, SLOT( slotCreatePost( const QList<QVariant>&, const QVariant& ) ),
       this, SLOT( slotError( int, const QString&, const QVariant& ) ), QVariant( i ) );
 }
 
-void Blogger1::removePosting( KBlog::BlogPosting *posting )
+void Blogger1::removePost( KBlog::BlogPost *post )
 {
  Q_D(Blogger1);
-  if ( !posting ) {
-    kError(5323) << "Blogger1::removePosting: posting is null pointer";
+  if ( !post ) {
+    kError(5323) << "Blogger1::removePost: post is null pointer";
     return;
   }
   unsigned int i = d->mCallCounter++;
-  d->mCallMap[ i ] = posting;
- kDebug(5323) << "Blogger1::removePosting: postingId=" << posting->postingId();
- QList<QVariant> args( d->defaultArgs( posting->postingId() ) );
- args << QVariant( true ); // Publish must be set to remove posting.
- d->mXmlRpcClient->call(
-   "blogger.deletePost", args,
-   this, SLOT( slotRemovePosting( const QList<QVariant>&, const QVariant& ) ),
-   this, SLOT( slotError( int, const QString&, const QVariant& ) ), QVariant( i ) );
+  d->mCallMap[ i ] = post;
+  kDebug(5323) << "Blogger1::removePost: postId=" << post->postId();
+  QList<QVariant> args( d->blogger1Args( post->postId() ) );
+  args << QVariant( true ); // Publish must be set to remove post.
+  d->mXmlRpcClient->call(
+    "blogger.deletePost", args,
+    this, SLOT( slotRemovePost( const QList<QVariant>&, const QVariant& ) ),
+    this, SLOT( slotError( int, const QString&, const QVariant& ) ), QVariant( i ) );
 }
 
 Blogger1Private::Blogger1Private() :
@@ -216,6 +202,19 @@ QList<QVariant> Blogger1Private::defaultArgs( const QString &id )
   return args;
 }
 
+// reimplemenet defaultArgs, since we may not use it virtually everywhere
+QList<QVariant> Blogger1Private::blogger1Args( const QString &id )
+{
+  Q_Q(Blogger1);
+  QList<QVariant> args;
+  args << QVariant( QString( "0123456789ABCDEF" ) );
+  if( !id.isEmpty() )
+    args << QVariant( id );
+  args << QVariant( q->username() )
+          << QVariant( q->password() );
+  return args;
+}
+
 void Blogger1Private::slotFetchUserInfo(
     const QList<QVariant> &result, const QVariant &id )
 {
@@ -277,57 +276,58 @@ void Blogger1Private::slotListBlogs(
   }
 }
 
-void Blogger1Private::slotListRecentPostings(
+void Blogger1Private::slotListRecentPosts(
     const QList<QVariant> &result, const QVariant &id )
 {
   Q_Q(Blogger1);
   int count = id.toInt(); // not sure if needed, actually the API should
 // not give more posts
 
-  kDebug(5323) << "Blog::slotListRecentPostings";
+  kDebug(5323) << "Blog::slotListRecentPosts";
   kDebug(5323) << "TOP:" << result[0].typeName();
 
-  QList <BlogPosting> fetchedPostingList;
+  QList <BlogPost> fetchedPostList;
 
   if ( result[0].type() != QVariant::List ) {
-    kError(5323) << "Could not fetch list of postings out of the"
+    kError(5323) << "Could not fetch list of posts out of the"
                  << "result from the server, not a list.";
     emit q->error( Blogger1::ParsingError,
-                         i18n( "Could not fetch list of postings out of the "
+                         i18n( "Could not fetch list of posts out of the "
                                "result from the server, not a list." ) );
   } else {
     const QList<QVariant> postReceived = result[0].toList();
     QList<QVariant>::ConstIterator it = postReceived.begin();
     QList<QVariant>::ConstIterator end = postReceived.end();
     for ( ; it != end; ++it ) {
-      BlogPosting posting;
+      BlogPost post;
       kDebug(5323) << "MIDDLE:" << ( *it ).typeName();
       const QMap<QString, QVariant> postInfo = ( *it ).toMap();
-      if ( readPostingFromMap( &posting, postInfo ) ) {
-        kDebug(5323) << "Posting with ID:"
-                    << posting.postingId()
-                    << "appended in fetchedPostingList";
-        fetchedPostingList.append( posting );
+      if ( readPostFromMap( &post, postInfo ) ) {
+        kDebug(5323) << "Post with ID:"
+                    << post.postId()
+                    << "appended in fetchedPostList";
+        post.setStatus( BlogPost::Fetched );
+        fetchedPostList.append( post );
       } else {
-        kError(5323) << "readPostingFromMap failed!";
+        kError(5323) << "readPostFromMap failed!";
         emit q->error( Blogger1::ParsingError,
-                             i18n( "Could not read posting." ) );
+                             i18n( "Could not read post." ) );
        }
        if( --count == 0 )
          break;
      }
    }
-   kDebug(5323) << "Emitting listRecentPostingsFinished()";
-   emit q->listedRecentPostings(fetchedPostingList);
+   kDebug(5323) << "Emitting listRecentPostsFinished()";
+   emit q->listedRecentPosts(fetchedPostList);
 }
 
-void Blogger1Private::slotFetchPosting(
+void Blogger1Private::slotFetchPost(
     const QList<QVariant> &result, const QVariant &id )
 {
   Q_Q(Blogger1);
-  kDebug(5323) << "Blog::slotFetchPosting";
+  kDebug(5323) << "Blog::slotFetchPost";
 
-  KBlog::BlogPosting* posting = mCallMap[ id.toInt() ];
+  KBlog::BlogPost* post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
   //array of structs containing ISO.8601
@@ -335,101 +335,111 @@ void Blogger1Private::slotFetchPosting(
   // TODO: Time zone for the dateCreated!
   kDebug (5323) << "TOP:" << result[0].typeName();
   if ( result[0].type() != QVariant::Map ) {
-    kError(5323) << "Could not fetch posting out of the result from"
+    kError(5323) << "Could not fetch post out of the result from "
                   << "the server.";
-    emit q->error( Blogger1::ParsingError,
-                        i18n( "Could not fetch posting out of the result from "
-                              "the server." ), posting );
-    posting->setError( i18n( "Could not fetch posting out of the "
+    emit q->errorPost( Blogger1::ParsingError,
+                          i18n( "Could not fetch post out of the result"
+                                "from the server." ), post );
+    post->setError( i18n( "Could not fetch post out of the "
                               "result from the server." ) );
-    posting->setStatus( BlogPosting::Error );
+    post->setStatus( BlogPost::Error );
   } else {
     const QMap<QString, QVariant> postInfo = result[0].toMap();
-    if ( readPostingFromMap( posting, postInfo ) ) {
-      kDebug(5323) << "Emitting fetchedPosting( posting.postingId()="
-                   << posting->postingId() << ");";
-      posting->setStatus( BlogPosting::Fetched );
-      emit q->fetchedPosting( posting );
+    if ( readPostFromMap( post, postInfo ) ) {
+      kDebug(5323) << "Emitting fetchedPost( post.postId()="
+                   << post->postId() << ");";
+      post->setStatus( BlogPost::Fetched );
+      emit q->fetchedPost( post );
     } else {
-      kError(5323) << "readPostingFromMap failed!";
-      emit q->error( Blogger1::ParsingError,
-                          i18n( "Could not read posting." ), posting );
-      posting->setError( i18n( "Could not read posting." ) );
-      posting->setStatus( BlogPosting::Error );
+      kError(5323) << "readPostFromMap failed!";
+      emit q->errorPost( Blogger1::ParsingError,
+                            i18n( "Could not read post." ), post );
+      post->setError( i18n( "Could not read post." ) );
+      post->setStatus( BlogPost::Error );
     }
   }
 
 }
 
-void Blogger1Private::slotCreatePosting(
+void Blogger1Private::slotCreatePost(
     const QList<QVariant> &result, const QVariant &id )
 {
   Q_Q(Blogger1);
-  KBlog::BlogPosting* posting = mCallMap[ id.toInt() ];
+  KBlog::BlogPost* post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
-  kDebug(5323) << "Blog::slotCreatePosting";
+  kDebug(5323) << "Blog::slotCreatePost";
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
   kDebug (5323) << "TOP:" << result[0].typeName();
-  if ( result[0].type() != QVariant::String ) {
-    kError(5323) << "Could not read the postingId, not a string.";
-    emit q->error( Blogger1::ParsingError,
-                        i18n( "Could not read the postingId, not a string." ), posting );
+  if ( result[0].type() != QVariant::String && result[0].type() != QVariant::Int ) {
+    kError(5323) << "Could not read the postId, not a string or an integer.";
+    emit q->errorPost( Blogger1::ParsingError,
+                          i18n( "Could not read the postId, not a string or an integer." ),
+                          post );
   } else {
-    posting->setPostingId( result[0].toString() );
-    posting->setStatus( KBlog::BlogPosting::Created );
-    emit q->createdPosting( posting );
-    kDebug(5323) << "emitting createdPosting()" <<
-             "for" << result[0].toInt();
+    QString id;
+    if( result[0].type() == QVariant::String )
+      id = result[0].toString();
+    if( result[0].type() == QVariant::Int )
+      id = QString( "%1" ).arg( result[0].toInt() );
+    post->setPostId( id );
+    post->setStatus( KBlog::BlogPost::Created );
+    emit q->createdPost( post );
+    kDebug(5323) << "emitting createdPost()" <<
+             "for title: \"" << post->title() << 
+             "\" server id: " << id;
   }
 
 }
 
-void Blogger1Private::slotModifyPosting(
+void Blogger1Private::slotModifyPost(
     const QList<QVariant> &result, const QVariant &id )
 {
   Q_Q(Blogger1);
-  KBlog::BlogPosting* posting = mCallMap[ id.toInt() ];
+  KBlog::BlogPost* post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
-  kDebug(5323) << "Blog::slotModifyPosting";
+  kDebug(5323) << "Blog::slotModifyPost";
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
   kDebug(5323) << "TOP:" << result[0].typeName();
   if ( result[0].type() != QVariant::Bool ) {
     kError(5323) << "Could not read the result, not a boolean.";
-    emit q->error( Blogger1::ParsingError,
-                        i18n( "Could not read the result, not a boolean." ), posting );
+    emit q->errorPost( Blogger1::ParsingError,
+                          i18n( "Could not read the result, not a boolean." ),
+                          post );
   } else {
-    posting->setStatus( KBlog::BlogPosting::Modified );
-    emit q->modifiedPosting( posting );
-    kDebug(5323) << "emitting modifiedPosting()";
+    post->setStatus( KBlog::BlogPost::Modified );
+    emit q->modifiedPost( post );
+    kDebug(5323) << "emitting modifiedPost() for title: \""
+                            << post->title() << "\"";
   }
 }
 
-void Blogger1Private::slotRemovePosting(
+void Blogger1Private::slotRemovePost(
     const QList<QVariant> &result, const QVariant &id )
 {
   Q_Q(Blogger1);
-  KBlog::BlogPosting* posting = mCallMap[ id.toInt() ];
+  KBlog::BlogPost* post = mCallMap[ id.toInt() ];
   mCallMap.remove( id.toInt() );
 
-  kDebug(5323) << "Blog::slotRemovePosting";
+  kDebug(5323) << "Blog::slotRemovePost";
   //array of structs containing ISO.8601
   // dateCreated, String userid, String postid, String content;
   // TODO: Time zone for the dateCreated!
   kDebug(5323) << "TOP:" << result[0].typeName();
   if ( result[0].type() != QVariant::Bool ) {
     kError(5323) << "Could not read the result, not a boolean.";
-    emit q->error( Blogger1::ParsingError,
-                        i18n( "Could not read the result, not a boolean." ), posting );
+    emit q->errorPost( Blogger1::ParsingError,
+                          i18n( "Could not read the result, not a boolean." ),
+                          post );
   } else {
-    posting->setStatus( KBlog::BlogPosting::Removed );
-    emit q->removedPosting( posting );
-    kDebug(5323) << "emitting removedPosting()";
+    post->setStatus( KBlog::BlogPost::Removed );
+    emit q->removedPost( post );
+    kDebug(5323) << "emitting removedPost()";
   }
 }
 
@@ -439,13 +449,13 @@ void Blogger1Private::slotError( int number,
 {
   Q_Q(Blogger1);
   Q_UNUSED( number );
-  BlogPosting *posting = mCallMap[ id.toInt() ];
+  BlogPost *post = mCallMap[ id.toInt() ];
 
-  emit q->error( Blogger1::XmlRpc, errorString, posting );
+  emit q->errorPost( Blogger1::XmlRpc, errorString, post );
 }
 
-bool Blogger1Private::readPostingFromMap(
-    BlogPosting *post, const QMap<QString, QVariant> &postInfo )
+bool Blogger1Private::readPostFromMap(
+    BlogPost *post, const QMap<QString, QVariant> &postInfo )
 {
   // FIXME: integrate error handling
   if ( !post ) {
@@ -463,7 +473,7 @@ bool Blogger1Private::readPostingFromMap(
   if ( dt.isValid() && !dt.isNull() ) {
     post->setModificationDateTime( dt );
   }
-  post->setPostingId( postInfo["postid"].toString() );
+  post->setPostId( postInfo["postid"].toString() );
 
   QString title( postInfo["title"].toString() );
   QString description( postInfo["description"].toString() );
@@ -490,4 +500,33 @@ bool Blogger1Private::readPostingFromMap(
   return true;
 }
 
+bool Blogger1Private::readArgsFromPost(
+    QList<QVariant> *args, const BlogPost& post )
+{
+  if ( !args ) {
+    return false;
+  }
+  QStringList categories = post.categories();
+  QString content = "<title>" + post.title() + "</title>";
+  QStringList::const_iterator it;
+  for ( it = categories.constBegin(); it != categories.constEnd(); ++it ) {
+    content += "<category>" + *it + "</category>";
+  }
+  content += post.content();
+  *args << QVariant( content );
+  *args << QVariant( !post.isPrivate() );
+  return true;
+}
+
+QString Blogger1Private::getCallFromFunction( FunctionToCall type )
+{
+  switch ( type ) {
+    case GetRecentPosts: return "blogger.getRecentPosts";
+    case CreatePost:        return "blogger.newPost";
+    case ModifyPost:       return "blogger.editPost";
+    case FetchPost:        return "blogger.getPost";
+    default: return QString::null;
+  }
+}
+
 #include "blogger1.moc"
