@@ -23,16 +23,16 @@
   This file is part of the API for handling calendar data and
   defines the Attachment class.
 
-  @author Michael Brade
+  @author Michael Brade \<brade@kde.org\>
 */
 
 #ifndef KCAL_ATTACHMENT_H
 #define KCAL_ATTACHMENT_H
 
 #include "listbase.h"
-#include "kcal.h"
+#include "kcal_export.h"
 
-#include <QString>
+#include <QtCore/QString>
 
 namespace KCal {
 
