@@ -159,7 +159,7 @@ static QString eventViewerFormatAttendees( Incidence *event )
   Attendee::List attendees = event->attendees();
   if ( attendees.count() ) {
     KIconLoader *iconLoader = KIconLoader::global();
-    const QString iconPath = iconLoader->iconPath( "mail", K3Icon::Small );
+    const QString iconPath = iconLoader->iconPath( "mail", KIconLoader::Small );
 
     // Add organizer link
     tmpStr += eventViewerAddTag( "h3", i18n( "Organizer" ) );
@@ -221,7 +221,7 @@ static QString eventViewerFormatBirthday( Event *event )
   QString email_1= event->customProperty( "KABC", "EMAIL-1" );
 
   KIconLoader *iconLoader = KIconLoader::global();
-  const QString iconPath = iconLoader->iconPath( "mail", K3Icon::Small );
+  const QString iconPath = iconLoader->iconPath( "mail", KIconLoader::Small );
   //TODO: add a tart icon
   QString tmpString = "<ul>";
   tmpString += linkPerson( email_1, name_1, uid_1, iconPath );
@@ -247,16 +247,16 @@ static QString eventViewerFormatHeader( Incidence *incidence )
     tmpStr += "<td>";
 
     if ( incidence->type() == "Todo" ) {
-      tmpStr += "<img src=\"" + iconLoader->iconPath( "todo", K3Icon::Small ) + "\">";
+      tmpStr += "<img src=\"" + iconLoader->iconPath( "todo", KIconLoader::Small ) + "\">";
     }
     if ( incidence->isAlarmEnabled() ) {
-      tmpStr += "<img src=\"" + iconLoader->iconPath( "bell", K3Icon::Small ) + "\">";
+      tmpStr += "<img src=\"" + iconLoader->iconPath( "bell", KIconLoader::Small ) + "\">";
     }
     if ( incidence->recurs() ) {
-      tmpStr += "<img src=\"" + iconLoader->iconPath( "recur", K3Icon::Small ) + "\">";
+      tmpStr += "<img src=\"" + iconLoader->iconPath( "recur", KIconLoader::Small ) + "\">";
     }
     if ( incidence->isReadOnly() ) {
-      tmpStr += "<img src=\"" + iconLoader->iconPath( "readonlyevent", K3Icon::Small ) + "\">";
+      tmpStr += "<img src=\"" + iconLoader->iconPath( "readonlyevent", KIconLoader::Small ) + "\">";
     }
 
     tmpStr += "</td>";
@@ -285,7 +285,7 @@ static QString eventViewerFormatEvent( Event *event )
   }
 
   tmpStr += "<tr>";
-  if ( event->floats() ) {
+  if ( event->allDay() ) {
     if ( event->isMultiDay() ) {
       tmpStr += "<td align=\"right\"><b>" + i18n( "Time" ) + "</b></td>";
       tmpStr += "<td>" + i18nc("<beginTime> - <endTime>","%1 - %2",
@@ -301,16 +301,16 @@ static QString eventViewerFormatEvent( Event *event )
     if ( event->isMultiDay() ) {
       tmpStr += "<td align=\"right\"><b>" + i18n( "Time" ) + "</b></td>";
       tmpStr += "<td>" +
-	        i18nc( "<beginTime> - <endTime>","%1 - %2",
-		       event->dtStartStr( true, event->dtStart().timeSpec() ),
-		       event->dtEndStr( true, event->dtEnd().timeSpec() ) ) + "</td>";
+                i18nc( "<beginTime> - <endTime>","%1 - %2",
+                       event->dtStartStr( true, event->dtStart().timeSpec() ),
+                       event->dtEndStr( true, event->dtEnd().timeSpec() ) ) + "</td>";
     } else {
       tmpStr += "<td align=\"right\"><b>" + i18n( "Time" ) + "</b></td>";
       if ( event->hasEndDate() && event->dtStart() != event->dtEnd() ) {
         tmpStr += "<td>" +
-	          i18nc( "<beginTime> - <endTime>","%1 - %2",
-			 event->dtStartTimeStr( true, event->dtStart().timeSpec() ),
-			 event->dtEndTimeStr( true, event->dtEnd().timeSpec() ) ) + "</td>";
+                  i18nc( "<beginTime> - <endTime>","%1 - %2",
+                         event->dtStartTimeStr( true, event->dtStart().timeSpec() ),
+                         event->dtEndTimeStr( true, event->dtEnd().timeSpec() ) ) + "</td>";
       } else {
         tmpStr += "<td>" + event->dtStartTimeStr( true, event->dtStart().timeSpec() ) + "</td>";
       }
@@ -455,8 +455,9 @@ static QString eventViewerFormatFreeBusy( FreeBusy *fb )
 
   QList<Period> periods = fb->busyPeriods();
 
-  QString text = eventViewerAddTag( "em",
-                                    eventViewerAddTag( "b", i18n( "Busy:" ) ) );
+  QString text =
+    eventViewerAddTag( "em",
+                       eventViewerAddTag( "b", i18nc( "tag for busy periods list", "Busy:" ) ) );
 
   QList<Period>::iterator it;
   for ( it = periods.begin(); it != periods.end(); ++it ) {
@@ -465,15 +466,15 @@ static QString eventViewerFormatFreeBusy( FreeBusy *fb )
       int dur = per.duration().asSeconds();
       QString cont;
       if ( dur >= 3600 ) {
-        cont += i18np( "1 hour ", "%1 hours ", dur / 3600 );
+        cont += i18ncp( "hours part of duration", "1 hour ", "%1 hours ", dur / 3600 );
         dur %= 3600;
       }
       if ( dur >= 60 ) {
-        cont += i18np( "1 minute ", "%1 minutes ", dur / 60 );
+        cont += i18ncp( "minutes part duration", "1 minute ", "%1 minutes ", dur / 60 );
         dur %= 60;
       }
       if ( dur > 0 ) {
-        cont += i18np( "1 second", "%1 seconds", dur );
+        cont += i18ncp( "seconds part of duration", "1 second", "%1 seconds", dur );
       }
       text += i18nc( "startDate for duration", "%1 for %2",
                      KGlobal::locale()->formatDateTime(
@@ -499,6 +500,7 @@ static QString eventViewerFormatFreeBusy( FreeBusy *fb )
   return tmpStr;
 }
 
+//@cond PRIVATE
 class KCal::IncidenceFormatter::EventViewerVisitor : public IncidenceBase::Visitor
 {
   public:
@@ -530,6 +532,7 @@ class KCal::IncidenceFormatter::EventViewerVisitor : public IncidenceBase::Visit
   protected:
     QString mResult;
 };
+//@endcond
 
 QString IncidenceFormatter::extensiveDisplayString( IncidenceBase *incidence )
 {
@@ -588,7 +591,7 @@ static QString invitationDetailsEvent( Event *event )
   html += invitationRow( i18n( "Where:" ), sLocation );
 
   // Meeting Start Time Row
-  if ( ! event->floats() ) {
+  if ( ! event->allDay() ) {
     tmp = i18nc( "%1: Start Date, %2: Start Time", "%1 %2",
                  event->dtStartDateStr(), event->dtStartTimeStr() );
   } else {
@@ -599,10 +602,10 @@ static QString invitationDetailsEvent( Event *event )
 
   // Meeting End Time Row
   if ( event->hasEndDate() ) {
-    if ( ! event->floats() ) {
+    if ( ! event->allDay() ) {
       tmp =  i18nc( "%1: End Date, %2: End Time", "%1 %2",
                     event->dtEndDateStr( true, event->dtEnd().timeSpec() ),
-		    event->dtEndTimeStr( true, event->dtEnd().timeSpec() ) );
+                    event->dtEndTimeStr( true, event->dtEnd().timeSpec() ) );
     } else {
       tmp = i18nc( "%1: End Date", "%1 (time unspecified)",
                    event->dtEndDateStr( true, event->dtEnd().timeSpec() ) );
@@ -613,7 +616,7 @@ static QString invitationDetailsEvent( Event *event )
   html += invitationRow( i18n( "End Time:" ), tmp );
 
   // Meeting Duration Row
-  if ( !event->floats() && event->hasEndDate() ) {
+  if ( !event->allDay() && event->hasEndDate() ) {
     tmp.clear();
     QTime sDuration( 0, 0, 0 ), t;
     int secs = event->dtStart().secsTo( event->dtEnd() );
@@ -636,7 +639,7 @@ static QString invitationDetailsEvent( Event *event )
 
 static QString invitationDetailsTodo( Todo *todo )
 {
-  // Task details are formatted into an HTML table
+  // To-do details are formatted into an HTML table
   if ( !todo ) {
     return QString();
   }
@@ -704,15 +707,15 @@ static QString invitationDetailsFreeBusy( FreeBusy *fb )
       int dur = per.duration().asSeconds();
       QString cont;
       if ( dur >= 3600 ) {
-        cont += i18np( "1 hour ", "%1 hours ", dur / 3600 );
+        cont += i18ncp( "hours part of duration", "1 hour ", "%1 hours ", dur / 3600 );
         dur %= 3600;
       }
       if ( dur >= 60 ) {
-        cont += i18np( "1 minute", "%1 minutes ", dur / 60 );
+        cont += i18ncp( "minutes part of duration", "1 minute", "%1 minutes ", dur / 60 );
         dur %= 60;
       }
       if ( dur > 0 ) {
-        cont += i18np( "1 second", "%1 seconds", dur );
+        cont += i18ncp( "seconds part of duration", "1 second", "%1 seconds", dur );
       }
       html += invitationRow(
         QString(), i18nc( "startDate for duration", "%1 for %2",
@@ -748,21 +751,21 @@ static QString invitationHeaderEvent( Event *event, ScheduleMessage *msg )
   }
 
   switch ( msg->method() ) {
-  case Scheduler::Publish:
+  case iTIPPublish:
     return i18n( "This event has been published" );
-  case Scheduler::Request:
+  case iTIPRequest:
     if ( event->revision() > 0 ) {
       return i18n( "<h2>This meeting has been updated</h2>" );
     } else {
       return i18n( "You have been invited to this meeting" );
     }
-  case Scheduler::Refresh:
+  case iTIPRefresh:
     return i18n( "This invitation was refreshed" );
-  case Scheduler::Cancel:
+  case iTIPCancel:
     return i18n( "This meeting has been canceled" );
-  case Scheduler::Add:
+  case iTIPAdd:
     return i18n( "Addition to the meeting invitation" );
-  case Scheduler::Reply:
+  case iTIPReply:
   {
     Attendee::List attendees = event->attendees();
     if( attendees.count() == 0 ) {
@@ -830,11 +833,11 @@ static QString invitationHeaderEvent( Event *event, ScheduleMessage *msg )
     }
     break;
   }
-  case Scheduler::Counter:
+  case iTIPCounter:
     return i18n( "Sender makes this counter proposal" );
-  case Scheduler::Declinecounter:
+  case iTIPDeclineCounter:
     return i18n( "Sender declines the counter proposal" );
-  case Scheduler::NoMethod:
+  case iTIPNoMethod:
     return i18n( "Error: iMIP message with unknown method: '%1'", msg->method() );
   }
   return QString();
@@ -847,21 +850,21 @@ static QString invitationHeaderTodo( Todo *todo, ScheduleMessage *msg )
   }
 
   switch ( msg->method() ) {
-  case Scheduler::Publish:
-    return i18n( "This task has been published" );
-  case Scheduler::Request:
+  case iTIPPublish:
+    return i18n( "This to-do has been published" );
+  case iTIPRequest:
     if ( todo->revision() > 0 ) {
-      return i18n( "This task has been updated" );
+      return i18n( "This to-do has been updated" );
     } else {
-      return i18n( "You have been assigned this task" );
+      return i18n( "You have been assigned this to-do" );
     }
-  case Scheduler::Refresh:
-    return i18n( "This task was refreshed" );
-  case Scheduler::Cancel:
-    return i18n( "This task was canceled" );
-  case Scheduler::Add:
-    return i18n( "Addition to the task" );
-  case Scheduler::Reply:
+  case iTIPRefresh:
+    return i18n( "This to-do was refreshed" );
+  case iTIPCancel:
+    return i18n( "This to-do was canceled" );
+  case iTIPAdd:
+    return i18n( "Addition to the to-do" );
+  case iTIPReply:
   {
     Attendee::List attendees = todo->attendees();
     if ( attendees.count() == 0 ) {
@@ -875,13 +878,13 @@ static QString invitationHeaderTodo( Todo *todo, ScheduleMessage *msg )
     Attendee *attendee = *attendees.begin();
     switch( attendee->status() ) {
     case Attendee::NeedsAction:
-      return i18n( "Sender indicates this task assignment still needs some action" );
+      return i18n( "Sender indicates this to-do assignment still needs some action" );
     case Attendee::Accepted:
-      return i18n( "Sender accepts this task" );
+      return i18n( "Sender accepts this to-do" );
     case Attendee::Tentative:
-      return i18n( "Sender tentatively accepts this task" );
+      return i18n( "Sender tentatively accepts this to-do" );
     case Attendee::Declined:
-      return i18n( "Sender declines this task" );
+      return i18n( "Sender declines this to-do" );
     case Attendee::Delegated:
     {
       QString delegate, dummy;
@@ -890,24 +893,24 @@ static QString invitationHeaderTodo( Todo *todo, ScheduleMessage *msg )
         delegate = attendee->delegate();
       }
       if ( !delegate.isEmpty() ) {
-        return i18n( "Sender has delegated this request for the task to %1", delegate );
+        return i18n( "Sender has delegated this request for the to-do to %1", delegate );
       }
-      return i18n( "Sender has delegated this request for the task " );
+      return i18n( "Sender has delegated this request for the to-do " );
     }
     case Attendee::Completed:
-      return i18n( "The request for this task is now completed" );
+      return i18n( "The request for this to-do is now completed" );
     case Attendee::InProcess:
       return i18n( "Sender is still processing the invitation" );
     default:
-      return i18n( "Unknown response to this task" );
+      return i18n( "Unknown response to this to-do" );
     }
     break;
   }
-  case Scheduler::Counter:
+  case iTIPCounter:
     return i18n( "Sender makes this counter proposal" );
-  case Scheduler::Declinecounter:
+  case iTIPDeclineCounter:
     return i18n( "Sender declines the counter proposal" );
-  case Scheduler::NoMethod:
+  case iTIPNoMethod:
     return i18n( "Error: iMIP message with unknown method: '%1'", msg->method() );
   }
   return QString();
@@ -921,17 +924,17 @@ static QString invitationHeaderJournal( Journal *journal, ScheduleMessage *msg )
   }
 
   switch ( msg->method() ) {
-  case Scheduler::Publish:
+  case iTIPPublish:
     return i18n( "This journal has been published" );
-  case Scheduler::Request:
+  case iTIPRequest:
     return i18n( "You have been assigned this journal" );
-  case Scheduler::Refresh:
+  case iTIPRefresh:
     return i18n( "This journal was refreshed" );
-  case Scheduler::Cancel:
+  case iTIPCancel:
     return i18n( "This journal was canceled" );
-  case Scheduler::Add:
+  case iTIPAdd:
     return i18n( "Addition to the journal" );
-  case Scheduler::Reply:
+  case iTIPReply:
   {
     Attendee::List attendees = journal->attendees();
     if ( attendees.count() == 0 ) {
@@ -965,11 +968,11 @@ static QString invitationHeaderJournal( Journal *journal, ScheduleMessage *msg )
     }
     break;
   }
-  case Scheduler::Counter:
+  case iTIPCounter:
     return i18n( "Sender makes this counter proposal" );
-  case Scheduler::Declinecounter:
+  case iTIPDeclineCounter:
     return i18n( "Sender declines the counter proposal" );
-  case Scheduler::NoMethod:
+  case iTIPNoMethod:
     return i18n( "Error: iMIP message with unknown method: '%1'", msg->method() );
   }
   return QString();
@@ -982,22 +985,23 @@ static QString invitationHeaderFreeBusy( FreeBusy *fb, ScheduleMessage *msg )
   }
 
   switch ( msg->method() ) {
-  case Scheduler::Publish:
+  case iTIPPublish:
     return i18n( "This free/busy list has been published" );
-  case Scheduler::Request:
+  case iTIPRequest:
     return i18n( "The free/busy list has been requested" );
-  case Scheduler::Refresh:
+  case iTIPRefresh:
     return i18n( "This free/busy list was refreshed" );
-  case Scheduler::Cancel:
+  case iTIPCancel:
     return i18n( "This free/busy list was canceled" );
-  case Scheduler::Add:
+  case iTIPAdd:
     return i18n( "Addition to the free/busy list" );
-  case Scheduler::NoMethod:
+  case iTIPNoMethod:
   default:
     return i18n( "Error: Free/Busy iMIP message with unknown method: '%1'", msg->method() );
   }
 }
 
+//@cond PRIVATE
 class KCal::IncidenceFormatter::ScheduleMessageVisitor : public IncidenceBase::Visitor
 {
   public:
@@ -1065,6 +1069,12 @@ class KCal::IncidenceFormatter::InvitationBodyVisitor
       return !mResult.isEmpty();
     }
 };
+//@endcond
+
+QString InvitationFormatterHelper::generateLinkURL( const QString &id )
+{
+  return id;
+}
 
 QString InvitationFormatterHelper::makeLink( const QString &id, const QString &text )
 {
@@ -1122,6 +1132,7 @@ QString IncidenceFormatter::formatICalInvitation( QString invitation, Calendar *
   html += "<table border=\"0\" cellspacing=\"0\"><tr><td>&nbsp;</td></tr><tr>";
 
 #if 0
+  // TODO: implement this
   html += helper->makeLinkURL( "accept", i18n( "[Enter this into my calendar]" ) );
   html += "</td><td> &nbsp; </td><td>";
 #endif
@@ -1130,16 +1141,17 @@ QString IncidenceFormatter::formatICalInvitation( QString invitation, Calendar *
 
   Incidence *incidence = dynamic_cast<Incidence*>( incBase );
   switch ( msg->method() ) {
-  case Scheduler::Publish:
-  case Scheduler::Request:
-  case Scheduler::Refresh:
-  case Scheduler::Add:
+  case iTIPPublish:
+  case iTIPRequest:
+  case iTIPRefresh:
+  case iTIPAdd:
   {
     if ( incidence && incidence->revision() > 0 ) {
-      html += "<td colspan=\"9\">";
       if ( incBase->type() == "Todo" ) {
-        html += helper->makeLink( "reply", i18n( "[Enter this into my task list]" ) );
+        html += "<td colspan=\"11\">";
+        html += helper->makeLink( "reply", i18n( "[Enter this into my to-do list]" ) );
       } else {
+        html += "<td colspan=\"9\">";
         html += helper->makeLink( "reply", i18n( "[Enter this into my calendar]" ) );
       }
       html += "</td></tr><tr>";
@@ -1147,46 +1159,46 @@ QString IncidenceFormatter::formatICalInvitation( QString invitation, Calendar *
     html += "<td>";
 
     // Accept
-    html += helper->makeLink( "accept", i18n( "[Accept]" ) );
+    html += helper->makeLink( "accept", i18nc( "accept to-do request", "[Accept]" ) );
     html += "</td><td> &nbsp; </td><td>";
     html += helper->makeLink( "accept_conditionally",
                               i18nc( "Accept conditionally", "[Accept cond.]" ) );
     html += "</td><td> &nbsp; </td><td>";
     // Decline
-    html += helper->makeLink( "decline", i18n( "[Decline]" ) );
+    html += helper->makeLink( "decline", i18nc( "decline to-do request", "[Decline]" ) );
     html += "</td><td> &nbsp; </td><td>";
 
     // Delegate
-    html += helper->makeLink( "delegate", i18n( "[Delegate]" ) );
+    html += helper->makeLink( "delegate", i18nc( "delegate to-do to another", "[Delegate]" ) );
     html += "</td><td> &nbsp; </td><td>";
 
     // Forward
-    html += helper->makeLink( "forward", i18n( "[Forward]" ) );
-#if 0
-    // TODO: implement this
-    html += "</b></a></td><td> &nbsp; </td><td>";
-    html += helper->makeLink( "check_calendar", i18n("[Check my calendar...]" ) );
-#endif
+    html += helper->makeLink( "forward", i18nc( "forward request to another", "[Forward]" ) );
+
+    if ( incBase->type() == "Event" ) {
+      html += "</b></a></td><td> &nbsp; </td><td>";
+      html += helper->makeLink( "check_calendar", i18n("[Check my calendar]" ) );
+    }
     break;
   }
 
-  case Scheduler::Cancel:
+  case iTIPCancel:
     // Cancel event from my calendar
     html += helper->makeLink( "cancel", i18n( "[Remove this from my calendar]" ) );
     break;
 
-  case Scheduler::Reply:
+  case iTIPReply:
     // Enter this into my calendar
     if ( incBase->type() == "Todo" ) {
-      html += helper->makeLink( "reply", i18n( "[Enter this into my task list]" ) );
+      html += helper->makeLink( "reply", i18n( "[Enter this into my to-do list]" ) );
     } else {
       html += helper->makeLink( "reply", i18n( "[Enter this into my calendar]" ) );
     }
     break;
 
-  case Scheduler::Counter:
-  case Scheduler::Declinecounter:
-  case Scheduler::NoMethod:
+  case iTIPCounter:
+  case iTIPDeclineCounter:
+  case iTIPNoMethod:
     break;
   }
 
@@ -1200,8 +1212,8 @@ QString IncidenceFormatter::formatICalInvitation( QString invitation, Calendar *
       html += string2HTML( sDescr ) + "</td></tr></table>";
     }
     QStringList comments = incidence->comments();
-    if ( ( msg->method() == Scheduler::Request ||
-           msg->method() == Scheduler::Cancel ) && !comments.isEmpty() ) {
+    if ( ( msg->method() == iTIPRequest ||
+           msg->method() == iTIPCancel ) && !comments.isEmpty() ) {
       html += "<br><u>" + i18n( "Comments:" ) +
               "</u><br><table border=\"0\"><tr><td>&nbsp;</td><td><ul>";
       for ( int i = 0; i < comments.count(); ++i ) {
@@ -1220,6 +1232,7 @@ QString IncidenceFormatter::formatICalInvitation( QString invitation, Calendar *
  *  Helper functions for the Incidence tooltips
  *******************************************************************/
 
+//@cond PRIVATE
 class KCal::IncidenceFormatter::ToolTipVisitor : public IncidenceBase::Visitor
 {
   public:
@@ -1257,14 +1270,14 @@ QString IncidenceFormatter::ToolTipVisitor::dateRangeText( Event *event )
   QString tmp;
   if ( event->isMultiDay() ) {
 
-    if ( event->floats() ) {
+    if ( event->allDay() ) {
       tmp = event->dtStartDateStr( true, event->dtStart().timeSpec() ).replace( " ", "&nbsp;" );
     } else {
       tmp = event->dtStartStr( true, event->dtStart().timeSpec() ).replace( " ", "&nbsp;" );
     }
     ret += "<br>" + i18nc( "Event start", "<i>From:</i>&nbsp;%1", tmp );
 
-    if ( event->floats() ) {
+    if ( event->allDay() ) {
       tmp = event->dtEndDateStr( true, event->dtStart().timeSpec() ).replace( " ", "&nbsp;" );
     } else {
       tmp = event->dtEndStr( true, event->dtEnd().timeSpec() ).replace( " ", "&nbsp;" );
@@ -1275,19 +1288,24 @@ QString IncidenceFormatter::ToolTipVisitor::dateRangeText( Event *event )
 
     ret += "<br>" +
            i18n( "<i>Date:</i>&nbsp;%1",
-                 event->dtStartDateStr( true, event->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) );
-    if ( !event->floats() ) {
-      if ( event->dtStartTimeStr( true, event->dtStart().timeSpec() ) == 
-	   event->dtEndTimeStr( true, event->dtEnd().timeSpec() ) ) { // to prevent 'Time: 17:00 - 17:00'
+                 event->dtStartDateStr(
+                   true, event->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) );
+    if ( !event->allDay() ) {
+      if ( event->dtStartTimeStr( true, event->dtStart().timeSpec() ) ==
+           event->dtEndTimeStr( true, event->dtEnd().timeSpec() ) ) {
+        // to prevent 'Time: 17:00 - 17:00'
         tmp = "<br>" +
               i18nc( "time for event, &nbsp; to prevent ugly line breaks", "<i>Time:</i>&nbsp;%1",
-                     event->dtStartTimeStr( true, event->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) );
+                     event->dtStartTimeStr(
+                       true, event->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) );
       } else {
         tmp = "<br>" +
               i18nc( "time range for event, &nbsp; to prevent ugly line breaks",
                      "<i>Time:</i>&nbsp;%1&nbsp;-&nbsp;%2",
-                     event->dtStartTimeStr( true, event->dtStart().timeSpec() ).replace( " ", "&nbsp;" ),
-                     event->dtEndTimeStr( true, event->dtEnd().timeSpec() ).replace( " ", "&nbsp;" ) );
+                     event->dtStartTimeStr(
+                       true, event->dtStart().timeSpec() ).replace( " ", "&nbsp;" ),
+                     event->dtEndTimeStr(
+                       true, event->dtEnd().timeSpec() ).replace( " ", "&nbsp;" ) );
       }
       ret += tmp;
     }
@@ -1298,27 +1316,31 @@ QString IncidenceFormatter::ToolTipVisitor::dateRangeText( Event *event )
 QString IncidenceFormatter::ToolTipVisitor::dateRangeText( Todo *todo )
 {
   QString ret;
-  bool floats( todo->floats() );
+  bool allDay( todo->allDay() );
   if ( todo->hasStartDate() ) {
     // No need to add <i> here. This is separated issue and each line
     // is very visible on its own. On the other hand... Yes, I like it
     // italics here :)
     ret += "<br>" + i18n( "<i>Start:</i>&nbsp;%1",
-                          ( floats ) ?
-                          ( todo->dtStartDateStr( true, false, todo->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) ) :
-                          ( todo->dtStartStr( true, false, todo->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) ) ) ;
+                          ( allDay ) ?
+                          ( todo->dtStartDateStr(
+                            true, false, todo->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) ) :
+                          ( todo->dtStartStr(
+                            true, false, todo->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) ) ) ;
   }
   if ( todo->hasDueDate() ) {
     ret += "<br>" + i18n( "<i>Due:</i>&nbsp;%1",
-                          ( floats ) ?
-                          ( todo->dtDueDateStr( true, todo->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) ) :
-                          ( todo->dtDueStr( true, todo->dtDue().timeSpec() ).replace( " ", "&nbsp;" ) ) );
+                          ( allDay ) ?
+                          ( todo->dtDueDateStr(
+                            true, todo->dtStart().timeSpec() ).replace( " ", "&nbsp;" ) ) :
+                          ( todo->dtDueStr(
+                            true, todo->dtDue().timeSpec() ).replace( " ", "&nbsp;" ) ) );
   }
   if ( todo->isCompleted() ) {
     ret += "<br>" +
            i18n( "<i>Completed:</i>&nbsp;%1", todo->completedStr().replace( " ", "&nbsp;" ) );
   } else {
-    ret += "<br>" + i18n( "%1 % completed", todo->percentComplete() );
+    ret += "<br>" + i18nc( "percent complete", "%1 % completed", todo->percentComplete() );
   }
 
   return ret;
@@ -1328,16 +1350,19 @@ QString IncidenceFormatter::ToolTipVisitor::dateRangeText( Journal *journal )
 {
   QString ret;
   if ( journal->dtStart().isValid() ) {
-    ret += "<br>" + i18n( "<i>Date:</i>&nbsp;%1", journal->dtStartDateStr( false,  journal->dtStart().timeSpec() ) );
+    ret += "<br>" +
+           i18n( "<i>Date:</i>&nbsp;%1",
+                 journal->dtStartDateStr( false, journal->dtStart().timeSpec() ) );
   }
   return ret;
 }
 
 QString IncidenceFormatter::ToolTipVisitor::dateRangeText( FreeBusy *fb )
 {
-  QString ret = "<br>" +
-                i18n( "<i>Period start:</i>&nbsp;%1",
-                      KGlobal::locale()->formatDateTime( fb->dtStart().dateTime() ) );
+  QString ret;
+  ret = "<br>" +
+        i18n( "<i>Period start:</i>&nbsp;%1",
+              KGlobal::locale()->formatDateTime( fb->dtStart().dateTime() ) );
   ret += "<br>" +
          i18n( "<i>Period start:</i>&nbsp;%1",
                KGlobal::locale()->formatDateTime( fb->dtEnd().dateTime() ) );
@@ -1398,6 +1423,7 @@ QString IncidenceFormatter::ToolTipVisitor::generateToolTip( Incidence *incidenc
   tmp += "</qt>";
   return tmp;
 }
+//@endcond
 
 QString IncidenceFormatter::toolTipString( IncidenceBase *incidence, bool richText )
 {
@@ -1413,6 +1439,22 @@ QString IncidenceFormatter::toolTipString( IncidenceBase *incidence, bool richTe
  *  Helper functions for the Incidence tooltips
  *******************************************************************/
 
+static QString mailBodyIncidence( Incidence *incidence )
+{
+  QString body;
+  if ( !incidence->summary().isEmpty() ) {
+    body += i18n( "Summary: %1\n", incidence->summary() );
+  }
+  if ( !incidence->organizer().isEmpty() ) {
+    body += i18n( "Organizer: %1\n", incidence->organizer().fullName() );
+  }
+  if ( !incidence->location().isEmpty() ) {
+    body += i18n( "Location: %1\n", incidence->location() );
+  }
+  return body;
+}
+
+//@cond PRIVATE
 class KCal::IncidenceFormatter::MailBodyVisitor : public IncidenceBase::Visitor
 {
   public:
@@ -1441,46 +1483,35 @@ class KCal::IncidenceFormatter::MailBodyVisitor : public IncidenceBase::Visitor
     QString mResult;
 };
 
-static QString mailBodyIncidence( Incidence *incidence )
-{
-  QString body;
-  if ( !incidence->summary().isEmpty() ) {
-    body += i18n( "Summary: %1\n", incidence->summary() );
-  }
-  if ( !incidence->organizer().isEmpty() ) {
-    body += i18n( "Organizer: %1\n", incidence->organizer().fullName() );
-  }
-  if ( !incidence->location().isEmpty() ) {
-    body += i18n( "Location: %1\n", incidence->location() );
-  }
-  return body;
-}
-
 bool IncidenceFormatter::MailBodyVisitor::visit( Event *event )
 {
   QString recurrence[]= {
     i18nc( "no recurrence", "None" ),
-    i18n( "Minutely" ),
-    i18n( "Hourly" ),
-    i18n( "Daily" ),
-    i18n( "Weekly" ),
-    i18n( "Monthly Same Day" ),
-    i18n( "Monthly Same Position" ),
-    i18n( "Yearly" ),
-    i18n( "Yearly" ),
-    i18n( "Yearly" )
+    i18nc( "event recurs by minutes", "Minutely" ),
+    i18nc( "event recurs by hours", "Hourly" ),
+    i18nc( "event recurs by days", "Daily" ),
+    i18nc( "event recurs by weeks", "Weekly" ),
+    i18nc( "event recurs same position (e.g. first monday) each month", "Monthly Same Position" ),
+    i18nc( "event recurs same day each month", "Monthly Same Day" ),
+    i18nc( "event recurs same month each year", "Yearly Same Month" ),
+    i18nc( "event recurs same day each year", "Yearly Same Day" ),
+    i18nc( "event recurs same position (e.g. first monday) each year", "Yearly Same Position" )
   };
 
   mResult = mailBodyIncidence( event );
-  mResult += i18n( "Start Date: %1\n", event->dtStartDateStr( true, event->dtStart().timeSpec() ) );
-  if ( !event->floats() ) {
-    mResult += i18n( "Start Time: %1\n", event->dtStartTimeStr( true, event->dtStart().timeSpec() ) );
+  mResult += i18n( "Start Date: %1\n",
+                   event->dtStartDateStr( true, event->dtStart().timeSpec() ) );
+  if ( !event->allDay() ) {
+    mResult += i18n( "Start Time: %1\n",
+                     event->dtStartTimeStr( true, event->dtStart().timeSpec() ) );
   }
   if ( event->dtStart() != event->dtEnd() ) {
-    mResult += i18n( "End Date: %1\n", event->dtEndDateStr( true, event->dtStart().timeSpec() ) );
+    mResult += i18n( "End Date: %1\n",
+                     event->dtEndDateStr( true, event->dtStart().timeSpec() ) );
   }
-  if ( !event->floats() ) {
-    mResult += i18n( "End Time: %1\n", event->dtEndTimeStr( true, event->dtStart().timeSpec() ) );
+  if ( !event->allDay() ) {
+    mResult += i18n( "End Time: %1\n",
+                     event->dtEndTimeStr( true, event->dtStart().timeSpec() ) );
   }
   if ( event->recurs() ) {
     Recurrence *recur = event->recurrence();
@@ -1493,9 +1524,9 @@ bool IncidenceFormatter::MailBodyVisitor::visit( Event *event )
       mResult += '\n';
     } else {
       if ( recur->duration() != -1 ) {
-// TODO_Recurrence: What to do with floating
+// TODO_Recurrence: What to do with all-day
         QString endstr;
-        if ( event->floats() ) {
+        if ( event->allDay() ) {
           endstr = KGlobal::locale()->formatDate( recur->endDate() );
         } else {
           endstr = KGlobal::locale()->formatDateTime( recur->endDateTime().dateTime() );
@@ -1519,15 +1550,19 @@ bool IncidenceFormatter::MailBodyVisitor::visit( Todo *todo )
   mResult = mailBodyIncidence( todo );
 
   if ( todo->hasStartDate() ) {
-    mResult += i18n( "Start Date: %1\n", todo->dtStartDateStr( true, false, todo->dtStart().timeSpec() ) );
-    if ( !todo->floats() ) {
-      mResult += i18n( "Start Time: %1\n", todo->dtStartTimeStr( true, false, todo->dtStart().timeSpec() ) );
+    mResult += i18n( "Start Date: %1\n",
+                     todo->dtStartDateStr( true, false, todo->dtStart().timeSpec() ) );
+    if ( !todo->allDay() ) {
+      mResult += i18n( "Start Time: %1\n",
+                       todo->dtStartTimeStr( true, false, todo->dtStart().timeSpec() ) );
     }
   }
   if ( todo->hasDueDate() ) {
-    mResult += i18n( "Due Date: %1\n", todo->dtDueDateStr( true, todo->dtStart().timeSpec() ) );
-    if ( !todo->floats() ) {
-      mResult += i18n( "Due Time: %1\n", todo->dtDueTimeStr( true, todo->dtStart().timeSpec() ) );
+    mResult += i18n( "Due Date: %1\n",
+                     todo->dtDueDateStr( true, todo->dtStart().timeSpec() ) );
+    if ( !todo->allDay() ) {
+      mResult += i18n( "Due Time: %1\n",
+                       todo->dtDueTimeStr( true, todo->dtStart().timeSpec() ) );
     }
   }
   QString details = todo->description();
@@ -1541,7 +1576,7 @@ bool IncidenceFormatter::MailBodyVisitor::visit( Journal *journal )
 {
   mResult = mailBodyIncidence( journal );
   mResult += i18n( "Date: %1\n", journal->dtStartDateStr( true, journal->dtStart().timeSpec() ) );
-  if ( !journal->floats() ) {
+  if ( !journal->allDay() ) {
     mResult += i18n( "Time: %1\n", journal->dtStartTimeStr( true, journal->dtStart().timeSpec() ) );
   }
   if ( !journal->description().isEmpty() ) {
@@ -1549,6 +1584,7 @@ bool IncidenceFormatter::MailBodyVisitor::visit( Journal *journal )
   }
   return !mResult.isEmpty();
 }
+//@endcond
 
 QString IncidenceFormatter::mailBodyString( IncidenceBase *incidence )
 {
