@@ -18,6 +18,18 @@
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA  02110-1301, USA.
 */
+/**
+  @file
+  This file is part of the API for handling calendar data and
+  defines the CalendarLocal class.
+
+  @brief
+  Classes to represents the result of an operation. It's meant to be used
+  as return value of functions for returning status and especially error
+  information.
+
+  @author Cornelius Schumacher \<schumacher@kde.org\>
+*/
 
 #include "kresult.h"
 
@@ -26,41 +38,77 @@
 
 using namespace KCal;
 
+/**
+  Private class that helps to provide binary compatibility between releases.
+  @internal
+*/
+//@cond PRIVATE
+class KCal::KResult::Private
+{
+  public:
+    Private()
+      : mType( Ok ),
+        mErrorType( NotAnError ),
+        mChainedResult( 0 )
+    {
+    }
+
+    Private( Type type )
+      : mType( type ),
+        mChainedResult( 0 )
+    {
+      if ( mType == Error ) {
+        mErrorType = Undefined;
+      } else {
+        mErrorType = NotAnError;
+      }
+    }
+
+    Private( ErrorType error, const QString &details )
+      : mType( Error ),
+        mErrorType( error ),
+        mDetails( details ),
+        mChainedResult( 0 )
+    {
+    }
+
+    Type mType;
+    ErrorType mErrorType;
+    QString mDetails;
+    KResult *mChainedResult;
+};
+//@endcond
+
 KResult::KResult()
-  : mType( Ok ), mErrorType( NotAnError ), mChainedResult( 0 ), d( 0 )
+  : d( new KCal::KResult::Private )
 {
 }
 
 KResult::KResult( Type type )
-  : mType( type ), mChainedResult( 0 ), d( 0 )
+  : d( new KCal::KResult::Private( type ) )
 {
-  if ( mType == Error ) {
-    mErrorType = Undefined;
-  } else {
-    mErrorType = NotAnError;
-  }
 }
 
 KResult::KResult( ErrorType error, const QString &details )
-  : mType( Error ), mErrorType( error ), mDetails( details ),
-    mChainedResult( 0 ), d( 0 )
+  : d( new KCal::KResult::Private( error, details ) )
 {
 }
 
 KResult::~KResult()
 {
-  delete mChainedResult;
+  delete d->mChainedResult;
+  delete d;
 }
 
 KResult::KResult( const KResult &o ) : d( 0 )
 {
-  mType = o.mType;
-  mErrorType = o.mErrorType;
-  mDetails = o.mDetails;
-  if ( o.mChainedResult ) {
-    mChainedResult = new KResult( *o.mChainedResult );
+  d->mType = o.d->mType;
+  d->mErrorType = o.d->mErrorType;
+  d->mDetails = o.d->mDetails;
+  if ( o.d->mChainedResult ) {
+    d->mChainedResult = new KResult( *o.d->mChainedResult );
   } else {
-    mChainedResult = 0;
+    d->mChainedResult = 0;
   }
 }
 
@@ -71,33 +119,33 @@ KResult::operator bool() const
 
 bool KResult::isOk() const
 {
-  return mType == Ok;
+  return d->mType == Ok;
 }
 
 bool KResult::isInProgress() const
 {
-  return mType == InProgress;
+  return d->mType == InProgress;
 }
 
 bool KResult::isError() const
 {
-  return mType == Error;
+  return d->mType == Error;
 }
 
 KResult::ErrorType KResult::error() const
 {
-  return mErrorType;
+  return d->mErrorType;
 }
 
 QString KResult::message() const
 {
-  switch ( mType ) {
+  switch ( d->mType ) {
   case Ok:
     return i18n( "Ok" );
   case InProgress:
     return i18n( "In progress" );
   case Error:
-    switch ( mErrorType ) {
+    switch ( d->mErrorType ) {
     case NotAnError:
       return i18n( "Not an error" );
     case Undefined:
@@ -125,28 +173,28 @@ QString KResult::message() const
 
 void KResult::setDetails( const QString &details )
 {
-  mDetails = details;
+  d->mDetails = details;
 }
 
 QString KResult::details() const
 {
-  return mDetails;
+  return d->mDetails;
 }
 
 KResult &KResult::chain( const KResult &result )
 {
-  mChainedResult = new KResult( result );
+  d->mChainedResult = new KResult( result );
   return *this;
 }
 
 bool KResult::hasChainedResult() const
 {
-  return mChainedResult;
+  return d->mChainedResult;
 }
 
 KResult KResult::chainedResult() const
 {
-  return *mChainedResult;
+  return *d->mChainedResult;
 }
 
 QString KResult::fullMessage() const
