@@ -3,8 +3,6 @@
   FILE: icaltime.c
   CREATOR: eric 02 June 2000
   
-  $Id: icaltime.c 539169 2006-05-09 21:09:27Z winterz $
-  $Locker:  $
     
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
      http://www.softwarestudio.org
@@ -26,10 +24,7 @@
 
  ======================================================================*/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
+#include "config-libical.h"
 #include "icaltime.h"
 #include <assert.h>
 #include <string.h>
