@@ -29,6 +29,7 @@
 
 #include "kmime_contentindex.h"
 
+#include <QHash>
 #include <QSharedData>
 #include <QtCore/QStringList>
 
@@ -112,3 +113,8 @@ ContentIndex& ContentIndex::operator =(const ContentIndex & other)
     d = other.d;
   return *this;
 }
+
+uint qHash( const KMime::ContentIndex &index )
+{ 
+  return qHash( index.toString() );
+}
