@@ -42,7 +42,7 @@
 #include <kconfig.h>
 #include <kstandarddirs.h>
 #include <kservicetypetrader.h>
-#include <klibloader.h>
+#include <kpluginloader.h>
 
 #include "resource.h"
 
@@ -110,7 +110,7 @@ ConfigWidget *Factory::configWidget( const QString &type, QWidget *parent )
   }
 
   KService::Ptr ptr = d->mTypeMap[ type ];
-  KLibFactory *factory = KLibLoader::self()->factory( ptr->library().toLatin1() );
+  KPluginFactory *factory = KPluginLoader( ptr->library().toLatin1() ).factory();
   if ( !factory ) {
     kDebug(5650) << "KRES::Factory::configWidget(): Factory creation failed"
                  << KLibLoader::self()->lastErrorMessage();
@@ -163,7 +163,7 @@ Resource *Factory::Private::resourceInternal( const QString &type, const KConfig
   }
 
   KService::Ptr ptr = mTypeMap[ type ];
-  KLibFactory *factory = KLibLoader::self()->factory( ptr->library().toLatin1() );
+  KPluginFactory *factory = KPluginLoader( ptr->library().toLatin1() ).factory();
   if ( !factory ) {
     kDebug(5650) << "KRES::Factory::resource(): Factory creation failed"
                  << KLibLoader::self()->lastErrorMessage();
