@@ -28,14 +28,14 @@
  * @author Michael Goffioul
  */
 
+#include "lzfu.h"
+
+#include <QtCore/QIODevice>
+
 #include <sys/types.h>
 #include <string.h>
 #include <stdio.h>
 
-#include <QIODevice>
-
-#include "lzfu.h"
-
 //#define DO_DEBUG
 
 //@cond IGNORE
