@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,10 +24,10 @@
 
 #include <tools.h>
 
-#include <QByteArray>
-#include <QDomElement>
-#include <QString>
-#include <QStringList>
+#include <QtCore/QByteArray>
+#include <QtXml/QDomElement>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
 
 namespace Syndication {
 namespace Atom {
@@ -116,6 +116,7 @@ Content::Format Content::mapTypeToFormat(const QString& typep,  const QString& s
         xmltypes.append(QString::fromUtf8("text/xml-external-parsed-entity"));
         xmltypes.append(QString::fromUtf8("application/xml-external-parsed-entity"));
         xmltypes.append(QString::fromUtf8("application/xml-dtd"));
+        xmltypes.append(QString::fromUtf8("text/x-dtd")); // from shared-mime-info
     }
     
     if (xmltypes.contains(type)
