@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,17 +20,17 @@
  *
  */
 
-#include "personimpl.h"
 #include "tools.h"
+#include "personimpl.h"
 
 #include <kcharsets.h>
 #include <kcodecs.h> 
 #include <kdatetime.h>
 
-#include <QByteArray>
-#include <QDateTime>
-#include <QRegExp>
-#include <QString>
+#include <QtCore/QByteArray>
+#include <QtCore/QDateTime>
+#include <QtCore/QRegExp>
+#include <QtCore/QString>
 
 #include <kdebug.h>
 
